@@ -1,9 +1,16 @@
 import requests
 
-SEARCH_URL = "http://34.121.111.173/v1/sequences"
+
+SEARCH_URL = "http://34.121.111.173/v1/query"
 
 
 def split_sequence(sequence: str, max_line_len: int = 80):
+    """
+    Split single-line FASTA sequence into multiple lines
+    :param sequence: FASTA sequence
+    :param max_line_len: Maximum sequence chars per line
+    :return: List of sequence lines
+    """
     line_len = 0
     read_chars = 0
     full_seq = list(sequence)
@@ -38,10 +45,10 @@ def split_sequence(sequence: str, max_line_len: int = 80):
 def search(sequence: str, min_match: float = 95.0, max_results: int = 50):
     """
     Search MycoLab Genbank API
-    :param sequence:
-    :param min_match:
-    :param max_results:
-    :return:
+    :param sequence: FASTA sequence
+    :param min_match: Minimum match accuracy
+    :param max_results: Maximum number of Genbank results
+    :return: Mycolab Genbank API Sequences
     """
 
     data = {'location': True, 'match': min_match, 'results': max_results, "sequence": sequence}
